hive-emacs.daemon-ranking

Daemon capacity, affinity, ranking, and selection.

Daemon capacity, affinity, ranking, and selection.
raw docstring

daemon-has-capacity?clj

(daemon-has-capacity? daemon)
(daemon-has-capacity? daemon max-lings)

Return true when DAEMON can accept another ling.

Return true when DAEMON can accept another ling.
sourceraw docstring

daemon-ling-countclj

(daemon-ling-count daemon)

Return the number of lings bound to DAEMON.

Return the number of lings bound to DAEMON.
sourceraw docstring

daemon-project-affinityclj

(daemon-project-affinity daemon project-id)
(daemon-project-affinity daemon project-id lookup-ling-fn)

Return the project-affinity score for DAEMON and PROJECT-ID.

Return the project-affinity score for DAEMON and PROJECT-ID.
sourceraw docstring

max-lings-per-daemonclj

source

score-daemonclj

(score-daemon daemon project-id)
(score-daemon daemon project-id lookup-ling-fn)

Return the composite selection score for DAEMON and PROJECT-ID.

Return the composite selection score for DAEMON and PROJECT-ID.
sourceraw docstring

select-daemonclj

(select-daemon store & [{:keys [project-id default-id]}])

Return the best daemon for a new ling spawn.

Return the best daemon for a new ling spawn.
sourceraw docstring

update-health-score!clj

(update-health-score! store daemon-id score)

Set DAEMON-ID's health score, clamped to 0..100.

Set DAEMON-ID's health score, clamped to 0..100.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries