hive-emacs.daemon-selection

Compatibility facade for daemon ranking, scoring, heartbeat, and redistribution.

Compatibility facade for daemon ranking, scoring, heartbeat, and redistribution.
raw docstring

compute-health-scoreclj

source

daemon-has-capacity?clj

source

daemon-ling-countclj

source

daemon-project-affinityclj

source

default-health-scoreclj

source

error-penaltyclj

source

error-penalty-maxclj

source

error-score-deltaclj

source

ewma-alphaclj

source

find-migration-candidatesclj

source

find-overloaded-daemonsclj

source

health-levelclj

source

healthy?clj

source

heartbeat!clj

source

latency-degraded-msclj

source

latency-healthy-msclj

source

latency-max-penaltyclj

source

latency-score-deltaclj

source

ling-load-deltaclj

source

ling-load-penalty-perclj

source

max-lings-per-daemonclj

source

max-migrations-per-cycleclj

source

migrate-ling!clj

source

overloaded-ling-thresholdclj

source

plan-redistributionclj

source

recovery-bonusclj

source

redistribute-lings!clj

source

redistribution-score-thresholdclj

source

redistribution-statusclj

source

score-daemonclj

source

select-daemonclj

source

update-health-score!clj

source

cljdoc builds & hosts documentation for Clojure/Script libraries