hive-emacs.schema

Malli contracts shared by ports, domain logic, tools, and proof facets.

Malli contracts shared by ports, domain logic, tools, and proof facets.
raw docstring

AddonInitResultclj

source

Daemonclj

source

DaemonStatusclj

source

HealthLevelclj

source

HealthScoreclj

source

HeartbeatReportclj

source

Lingclj

source

McpResponseclj

source

PingResultclj

source

Resultclj

source

RuntimePortsclj

source

schema-bundleclj

source

ScoreInputclj

source

ScoreSnapshotclj

source

Taskclj

source

Tasksclj

source

valid?clj

(valid? schema value)
source

validate!clj

(validate! schema value)

Return VALUE when it conforms; throw explainable boundary error otherwise.

Return VALUE when it conforms; throw explainable boundary error otherwise.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries