Clojure only.

hive-emacs.vessel

Host-neutral Emacs vessel capability.

A host adapter may translate this descriptor into its own vessel protocol. Context and capability lookups are injected runtime ports.

Host-neutral Emacs vessel capability.

A host adapter may translate this descriptor into its own vessel protocol.
Context and capability lookups are injected runtime ports.
raw docstring

create-emacs-vesselclj

(create-emacs-vessel)

Return a neutral vessel descriptor with no host implementation dependency.

Return a neutral vessel descriptor with no host implementation dependency.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries