Dependency-free loader for the Emacs-side hive-mcp bridge.
Dependency-free loader for the Emacs-side hive-mcp bridge.
(bridge-ready-elisp)Build Elisp that fails unless the loaded bridge exposes its required API.
Build Elisp that fails unless the loaded bridge exposes its required API.
(ensure-loaded! eval-fn)Ensure required bridge entrypoints are ready in Emacs.
EVAL-FN accepts Elisp plus timeout milliseconds and returns a map with :success.
Ensure required bridge entrypoints are ready in Emacs. EVAL-FN accepts Elisp plus timeout milliseconds and returns a map with :success.
(eval-with-bridge eval-fn code timeout-ms)Ensure bridge entrypoints are loaded, then evaluate CODE with TIMEOUT-MS. Returns the evaluator result map.
Ensure bridge entrypoints are loaded, then evaluate CODE with TIMEOUT-MS. Returns the evaluator result map.
(load-entrypoints-elisp)Build Elisp that requires and validates the bridge entrypoints.
Build Elisp that requires and validates the bridge entrypoints.
(load-path-elisp dirs)Build Elisp that adds directories to load-path.
Build Elisp that adds directories to load-path.
(resolve-elisp-dirs)Return compiled bridge and runtime directories found on the classpath.
Return compiled bridge and runtime directories found on the classpath.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |