Daemon capacity, affinity, ranking, and selection.
Daemon capacity, affinity, ranking, and selection.
(daemon-has-capacity? daemon)(daemon-has-capacity? daemon max-lings)Return true when DAEMON can accept another ling.
Return true when DAEMON can accept another ling.
(daemon-ling-count daemon)Return the number of lings bound to DAEMON.
Return the number of lings bound to DAEMON.
(daemon-project-affinity daemon project-id)(daemon-project-affinity daemon project-id lookup-ling-fn)Return the project-affinity score for DAEMON and PROJECT-ID.
Return the project-affinity score for DAEMON and PROJECT-ID.
(score-daemon daemon project-id)(score-daemon daemon project-id lookup-ling-fn)Return the composite selection score for DAEMON and PROJECT-ID.
Return the composite selection score for DAEMON and PROJECT-ID.
(select-daemon store & [{:keys [project-id default-id]}])Return the best daemon for a new ling spawn.
Return the best daemon for a new ling spawn.
(update-health-score! store daemon-id score)Set DAEMON-ID's health score, clamped to 0..100.
Set DAEMON-ID's health score, clamped to 0..100.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |