Malli contracts shared by ports, domain logic, tools, and proof facets.
Malli contracts shared by ports, domain logic, tools, and proof facets.
(validate! schema value)Return VALUE when it conforms; throw explainable boundary error otherwise.
Return VALUE when it conforms; throw explainable boundary error otherwise.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |