Host-neutral Emacs vessel capability.
A host adapter may translate this descriptor into its own vessel protocol. Context and capability lookups are injected runtime ports.
Host-neutral Emacs vessel capability. A host adapter may translate this descriptor into its own vessel protocol. Context and capability lookups are injected runtime ports.
(create-emacs-vessel)Return a neutral vessel descriptor with no host implementation dependency.
Return a neutral vessel descriptor with no host implementation dependency.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |